@@ -290,6 +290,149 @@ void DEF_data ()
       activate_buttons();
 }
 
+void DEF_accessibility()
+{
+    int diff = 0;
+    diff += CHECKBUTTON_mouse_accessibility -> value(0);
+    diff += CHECKBUTTON_keyboard_mouse -> value(0);
+    diff += CHECKBUTTON_onscreen_keyboard -> value(0);
+    diff += CHECKBUTTON_onscreen_keyboard_disable_change -> value(0);
+    diff += CHOICE_onscreen_keyboard_layout -> value(0);
+
+    if (diff)
+      activate_buttons();
+}
+
+void DEF_joystick ()
+{
+    int diff = 0;
+
+    if (SPINNER_joystick_dev -> value() != 0)
+      {
+        SPINNER_joystick_dev -> value(0);
+	diff += 1;
+      }
+    if (SPINNER_joystick_slowness -> value() != 15)
+      {
+	SPINNER_joystick_slowness -> value(15);
+	diff += 1;
+      }
+    if (SPINNER_joystick_threshold -> value() != 3200)
+      {
+	SPINNER_joystick_threshold -> value(3200);
+	diff += 1;
+      }
+    if (SPINNER_joystick_maxsteps -> value() != 7)
+      {
+	SPINNER_joystick_maxsteps -> value(7);
+	diff += 1;
+      }
+    if (SPINNER_joystick_hat_slowness -> value() != 15)
+      {
+	SPINNER_joystick_hat_slowness -> value(15);
+	diff += 1;
+      }
+    if (SPINNER_joystick_hat_timeout -> value() != 1000)
+      {
+	SPINNER_joystick_hat_timeout -> value(1000);
+	diff += 1;
+      }
+    if (CHECKBUTTON_joystick_buttons_ignore -> value() != 0)
+      {
+	CHECKBUTTON_joystick_buttons_ignore -> value(0);
+	diff += 1;
+      }
+    if(strlen(TEXTINPUT_joystick_buttons_ignore->value()) > 0)
+      {
+	TEXTINPUT_joystick_buttons_ignore->value("");
+	diff += 1;
+      }
+    TEXTINPUT_joystick_buttons_ignore->deactivate();
+    if (SPINNER_joystick_btn_brush -> value() != 255)
+      {
+	SPINNER_joystick_btn_brush -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_label -> value() != 255)
+      {
+	SPINNER_joystick_btn_label -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_new -> value() != 255)
+      {
+	SPINNER_joystick_btn_new -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_print -> value() != 255)
+      {
+	SPINNER_joystick_btn_print -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_shapes -> value() != 255)
+      {
+	SPINNER_joystick_btn_shapes -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_undo -> value() != 255)
+      {
+	SPINNER_joystick_btn_undo -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_eraser -> value() != 255)
+      {
+	SPINNER_joystick_btn_eraser -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_lines -> value() != 255)
+      {
+	SPINNER_joystick_btn_lines -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_open -> value() != 255)
+      {
+	SPINNER_joystick_btn_open -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_redo -> value() != 255)
+      {
+	SPINNER_joystick_btn_redo -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_stamp -> value() != 255)
+      {
+	SPINNER_joystick_btn_stamp -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_escape -> value() != 255)
+      {
+	SPINNER_joystick_btn_escape -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_magic -> value() != 255)
+      {
+	SPINNER_joystick_btn_magic -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_pgsetup -> value() != 255)
+      {
+	SPINNER_joystick_btn_pgsetup -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_save -> value() != 255)
+      {
+	SPINNER_joystick_btn_save -> value(255);
+	diff += 1;
+      }
+    if (SPINNER_joystick_btn_text -> value() != 255)
+      {
+	SPINNER_joystick_btn_text -> value(255);
+	diff += 1;
+      }
+
+    if (diff)
+      activate_buttons();
+}
+
 bool RNDBUT_askoverwrite_isdef()
 {
     if (ROUNDBUTTON_askbeforeoverwriting->value() == 1)
@@ -359,6 +502,16 @@ void CB_SetActualTabToDefaults ()
         DEF_data		();
         return;
     }
+    if ( TABE_accessibility -> visible () )
+    {
+        DEF_accessibility		();
+        return;
+    }
+    if ( TABE_joystick -> visible () )
+    {
+        DEF_joystick		();
+        return;
+    }
 }
 
 void CB_SetAllTabsToDefaults ()
@@ -370,4 +523,6 @@ void CB_SetAllTabsToDefaults ()
     DEF_printing();
     DEF_saving();
     DEF_data();
+    DEF_accessibility();
+    DEF_joystick();
 }
