@@ -12,6 +12,8 @@ extern void DEF_locale			();
 extern void DEF_printing		();
 extern void DEF_saving			();
 extern void DEF_data			();
+extern void DEF_accessibility		();
+extern void DEF_joystick		();
 
 extern bool CHKBUT_fulls_isdef          ();
 extern bool RNDBUT_scrnsz_isdef         ();
