@@ -91,9 +91,12 @@ void setup(int argc, char * argv[])
   int i;
   int show_usage;
   int exit_val;
+    
+#if !defined (__WIN32__) && !defined(__APPLE__) && !defined(__BEOS__)
   const struct paper * ppr;
   int max_papersizes;
-
+#endif
+    
   show_usage = 0;
   exit_val = 0;
 
@@ -188,8 +191,8 @@ void setup(int argc, char * argv[])
 
   bindtextdomain("tuxpaint-config", LOCALEDIR);
   /* Old version of glibc does not have bind_textdomain_codeset() */
-#if defined __GLIBC__ && __GLIBC__ == 2 && __GLIBC_MINOR__ >=2 || __GLIBC__ > 2 || __APPLE__
-  bind_textdomain_codeset("tuxpaint-config", "iso-8859-1");
+#if defined __WIN32 || __GLIBC__ && __GLIBC__ == 2 && __GLIBC_MINOR__ >=2 || __GLIBC__ > 2 || __APPLE__
+  bind_textdomain_codeset("tuxpaint-config", "UTF-8");
 #endif
   textdomain("tuxpaint-config");
 
